@@ -1,5 +1,4 @@
 import json
-import copy
 
 from flask import Response, request
 
@@ -34,8 +33,11 @@ class ErrorResponse(Response):
 class OptionsResponse(Response):
     """ Response that is returned for requests with the OPTION method
     """
-    def __init__(self, methods, resource):
-        headers = copy.deepcopy(DEFAULT_HEADERS)
+    def __init__(self, methods, resource, header=None):
+        if headers is None:
+            headers = {}
+
+        headers.update(DEFAULT_HEADERS)
         headers['Allow'] = ','.join(methods)
 
         headers['Link'].append('<%s>; rel=describedby' % resource.schema.url)
@@ -51,13 +53,16 @@ class ResourceResponse(Response):
     """
     autocorrect_location_header = False
 
-    def __init__(self, resource, status=200, **kwargs):
+    def __init__(self, resource, status=200, headers=None, **kwargs):
         """ Initialize the reponse.
 
         Sets content-type and link headers. Add an etag and makes the
         request conditional
         """
-        headers = copy.deepcopy(DEFAULT_HEADERS)
+        if headers is None:
+            headers = {}
+
+        headers.update(DEFAULT_HEADERS)
 
         headers['Content-Type'] = resource.content_type()
 
