@@ -8,7 +8,9 @@ from . import response
 
 from json_patch import PatchError
 from json_resource import ResourceNotFound, ValidationError, ResourceExists
-from .authorization import UnAuthorized, Forbidden
+from .authorization import (
+    UnAuthorized, Forbidden, ServiceUnavailable, Authorization
+)
 
 
 EXCEPTION_MAP = {
@@ -18,7 +20,8 @@ EXCEPTION_MAP = {
     PatchError: 400,
     ValueError: 400,
     UnAuthorized: 401,
-    Forbidden: 403
+    Forbidden: 403,
+    ServiceUnavailable: 503,
 }
 
 
@@ -32,6 +35,8 @@ class BaseView(object):
 
         if authorization:
             self.authorization = authorization
+        else:
+            self.authorization = Authorization()
 
     def __call__(self, **kwargs):
         """ Call the view as a function.
@@ -56,16 +61,23 @@ class BaseView(object):
         """
         return '%s-%s' % (self.rel, self.resource.schema['id'].split('.')[0])
 
-    def authorize(self, resource):
+    def check_authorization(self):
         """ Checks the authorization of a call.
 
         This is implemented in the `Authorization object.
         """
         try:
-            self.authorization.authorize(resource)
+            self.authorization.check_authorization()
         except AttributeError:
             pass
 
+    def authorize(self, resource, **kwargs):
+        """ Checks the authorization of a call to access a resource.
+
+        This is implemented in the `Authorization object.
+        """
+        self.authorization.authorize(resource, **kwargs)
+
     @property
     def options(self):
         """ Responds to OPTION requests. We simply return the supported methods.
@@ -109,7 +121,10 @@ class ResourceView(BaseView):
 
         Returns 404 NOT FOUND when the resource does not exist
         """
+        self.check_authorization()
+
         resource = self.resource(kwargs)
+
         resource.load()
         self.authorize(resource)
 
@@ -130,6 +145,8 @@ class ResourceView(BaseView):
         Return 422 Unprocessable Entity when the request can be parsed, but the
         resource is invalid according to the schema.
         """
+        self.check_authorization()
+
         resource = self.resource(json.loads(request.data))
 
         if resource.rel('create'):
@@ -156,12 +173,14 @@ class ResourceView(BaseView):
         Return 422 Unprocessable Entity when the request can be parsed, but the
         resource is invalid according to the schema.
         """
-        resource = self.resource(json.loads(request.data))
-        self.authorize(resource)
+        self.check_authorization()
+
+        resource = self.resource(kwargs)
         resource.load()
 
         patch = Patch(json.loads(request.data))
 
+        self.authorize(resource, patch=patch)
         resource.patch(patch)
         resource.save()
 
@@ -174,6 +193,8 @@ class ResourceView(BaseView):
 
         Returns 404 NOT FOUND when the resource does not exist
         """
+        self.check_authorization()
+
         resource = self.resource(kwargs)
         self.authorize(resource)
 
@@ -204,6 +225,8 @@ class ResourceCreateView(BaseView):
 
         A `Location` header will be sent with to location of the created user.
         """
+        self.check_authorization()
+
         resource = self.resource(json.loads(request.data))
         self.authorize(resource)
 
@@ -236,6 +259,8 @@ class CollectionView(ResourceView):
         Returns a list of resources. GET parameters can be used to sort and page
         and filter the response.
         """
+        self.check_authorization()
+
         resource = self.resource(kwargs)
         resource['meta'].update(request.args.to_dict())
 
